@@ -1989,26 +1989,30 @@ namespace IPod
 
     internal static class DatabaseHasher
     {
-        public static void Hash(string path, string firewireID)
+        internal static void Hash(string path, string firewireID)
+        {
+            byte [] hash = GetHash (path, firewireID);
+            using(BinaryWriter writer = new BinaryWriter(File.Open(path, FileMode.Open))) {
+                writer.Seek(0x58, SeekOrigin.Begin);
+                writer.Write(hash, 0, hash.Length);
+                writer.Flush();
+            }
+        }
+
+        public static byte [] GetHash (string path, string firewireID)
         {
             byte [] hash = null;
-
             using(BinaryReader reader = new BinaryReader(File.Open(path, FileMode.Open))) {
                 byte [] contents = new byte[reader.BaseStream.Length];
                 reader.Read(contents, 0, contents.Length);
-                
+
                 Zero(contents, 0x18, 8);
                 Zero(contents, 0x32, 20);
                 Zero(contents, 0x58, 20);
 
                 hash = Hash58.GenerateHash(firewireID, contents);
             }
-
-            using(BinaryWriter writer = new BinaryWriter(File.Open(path, FileMode.Open))) {
-                writer.Seek(0x58, SeekOrigin.Begin);
-                writer.Write(hash, 0, hash.Length);
-                writer.Flush();
-            }
+            return hash;
         }
 
         private static void Zero(byte [] buffer, int index, int length)
